pub struct Permanent<T: 'static> { /* private fields */ }Expand description
Handle that mimics a 'static reference.
Thread Safety: Can be used anywhere and does not produce any form of overhead.
Implementations
Sourceimpl<T: 'static> Permanent<T>
impl<T: 'static> Permanent<T>
Sourcepub unsafe fn drop_permanent(self)
pub unsafe fn drop_permanent(self)
Drop the stored value.
Safety
The caller MUST ensure that:
- No other copies of this
Permanent<T>(or any references derived from it) exist anywhere in the program. - This function is called exactly once for the allocated memory.